<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=eu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Ataria',
	'article' => 'Artikulu',
	'articles' => 'Artikuluak',
	'articles_auteur' => 'Egile honen artikuluak',
	'articles_populaires' => 'Artikulu arrakastatsuenak',
	'articles_rubrique' => 'Atal honetako artikuluak',
	'aucun_article' => 'Ez dago artikulurik helbide honetan',
	'aucun_auteur' => 'Ez dago egilerik helbide honetan',
	'aucun_site' => 'Ez dago gunerik helbide honetan',
	'aucune_breve' => 'Ez dago laburrik helbide honetan',
	'aucune_rubrique' => 'Ez dago atalik helbide honetan',
	'auteur' => 'Egile',
	'autres' => 'Beste',
	'autres_breves' => 'Beste berri laburrak',
	'autres_groupes_mots_clefs' => 'Beste gako-hitz taldeak',
	'autres_sites' => 'Beste guneak',

	// B
	'bonjour' => 'Agur',

	// C
	'commenter_site' => 'Guneari buruz iruzkina egin',
	'contact' => 'Harremanetarako',
	'copie_document_impossible' => 'Dokumentua ezin da kopiatu',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Azken eranskinak',
	'dernieres_breves' => 'Azken berri-laburrak',
	'derniers_articles' => 'Azken artikuluak',
	'derniers_commentaires' => 'Azken oharrak',
	'derniers_messages_forum' => 'Foroetan argitaratu azken berriak',

	// E
	'edition_mode_texte' => 'Honen edizioa testu formatuan :',
	'en_reponse' => 'Erantzunez',
	'en_resume' => 'Laburbilduz',
	'envoyer_message' => 'Mezua bidali',
	'espace_prive' => 'Eremu pribatua',

	// F
	'formats_acceptes' => 'Onartutako formatuak : @formats@.',

	// H
	'hierarchie_site' => 'Gunearen hierarkia',

	// J
	'jours' => 'Egun',

	// L
	'lien_connecter' => 'Konektatu',

	// M
	'meme_auteur' => 'Egile beretik',
	'meme_rubrique' => 'Atal berean',
	'memes_auteurs' => 'Egile beretik',
	'message' => 'Mezua',
	'messages_forum' => 'Mezuak',
	'messages_recents' => 'Foroetako azken mezuak',
	'mots_clef' => 'Gako-hitz',
	'mots_clefs' => 'Gako-hitz',
	'mots_clefs_meme_groupe' => 'Talde bereko gako-hitzak',

	// N
	'navigation' => 'Arakatu',
	'nom' => 'Izena',
	'nouveautes' => 'Azken berriak',
	'nouveautes_web' => 'Sareko azken berriak',
	'nouveaux_articles' => 'Artikulu berriak',
	'nouvelles_breves' => 'Azken berri-laburrak',

	// P
	'page_precedente' => 'Aurreko orrialdea',
	'page_suivante' => 'Hurrengo orrialdea',
	'par_auteur' => 'Egilea',
	'participer_site' => 'Guneko gora-beheretan parte har dezakezu eta zure artikuluak proposatu izena emanez. Segidan, emaila baten bidez, gunearen eremu pribatuan sartzeko zure atzipen-kodeak ukanen dituzu.',
	'plan_site' => 'Gunearen mapa',
	'popularite' => 'Arrakasta',
	'poster_message' => 'Mezua igorri',
	'proposer_site' => 'Atal honetan gehitzeko gune bat proposa dezakezu:',

	// R
	'repondre_article' => 'Artikuluari erantzun',
	'repondre_breve' => 'Berri-laburrari erantzun',
	'resultats_recherche' => 'Bilaketaren emaitzak',
	'retour_debut_forums' => 'Foroen hasierara itzuli',
	'rubrique' => 'Atal',
	'rubriques' => 'Atalak',

	// S
	'signatures_petition' => 'Sinadurak',
	'site_realise_avec_spip' => 'SPIPekin eraiki gunea',
	'sites_web' => 'Webguneak',
	'sous_rubriques' => 'Azpi-atalak',
	'spam' => 'Spam',
	'suite' => 'Segida',
	'sur_web' => 'Sarean',
	'syndiquer_rubrique' => 'Atal hau sindikatu',
	'syndiquer_site' => 'Gune guzia sindikatu',

	// T
	'texte_lettre_information' => 'Hona gunearen informazio gutuna',
	'texte_lettre_information_2' => 'Gutunak ondoko egunetik argitaratu artikulu eta berri-laburrak biltzen ditu',

	// V
	'ver_imprimer' => 'Inprimatzeko bertsioa',
	'voir_en_ligne' => 'Linean ikusi',
	'voir_squelette' => 'Orri hunen eskeletoa ikusi'
);
